@@ -14,14 +14,57 @@ import utils.sql_utils as sqlUtils
 import utils.table_utils as tableUtils
 import utils.generation as genUtils
 import utils.DatabaseManager as databaseManager
+DatabaseManager = databaseManager.DatabaseManager
 # import utils.local_db_management as local
 
 # pylint: disable=missing-function-docstring
 # pylint: disable=missing-class-docstring
 # pylint: disable=invalid-name
 
-def database():
-    return databaseManager.DatabaseManager()
+def database(**kwargs)->databaseManager.DatabaseManager:
+    '''
+        Instantiate a DatabaseManager class.
+
+        ----------
+
+
+        Keyword Arguments
+        -------------------------
+        [`name`=None] {str}
+            The name of the database.
+
+        [`credentials`=None] {dict}
+            The database credentials for a mySQL database.
+
+        [`summary_path`=None] {str}
+            The path to the summary file to load the database manager from.
+
+        Return {DatabaseManager}
+        ----------------------
+        An instance of the DatabaseManager class.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-05-2022 13:52:33
+        `memberOf`: colemen_database
+        `version`: 1.0
+        `method_name`: database
+        * @xxx [06-05-2022 13:58:01]: documentation for database
+    '''
+    db = databaseManager.DatabaseManager()
+    name = obj.get_kwarg(['name'],None,(str),**kwargs)
+    summary_path = obj.get_kwarg(['summary_path'],None,(str),**kwargs)
+    credentials = obj.get_kwarg(['credentials'],None,(dict),**kwargs)
+    if name is not None:
+        db.name = name
+    if credentials is not None:
+        db.credentials = credentials
+    if summary_path is not None:
+        db.load_from_summary(summary_path)
+    return db
+
+
 
 def new_database():
     return ColemenDatabase()
